@@ -6,7 +6,7 @@
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 from accounts.get_balance import GetBalance
 from blockchain.block.get_block import GetBlock
-from wallet.wallet import Wallet_Import
+from wallet.wallet_import import wallet_import
 
 
 def print_balance():
@@ -14,6 +14,6 @@ def print_balance():
     Prints the current wallet balance.
     """
 
-    balance = GetBalance(GetBlock(), Wallet_Import(-1, 0))
+    balance = GetBalance(GetBlock(), wallet_import(-1, 0))
     print(balance)
     return balance
